@@ -20,4 +20,9 @@ def list_nvme_volumes(nvme_device):
 @click.option('--dataset_type', default=None)
 def mount_dataset(dataset_type):
     vol = Volume()
-    vol.mount_dataset(dataset_type)
\ No newline at end of file
+    vol.mount_dataset(dataset_type)
+
+@dataset.command()
+def unmount_datasets():
+    vol = Volume()
+    vol.unmount_datasets()
\ No newline at end of file
